| Title: | PEcAn Package for Integration of the STICS Model |
|---|---|
| Description: | This module provides functions to link the STICS to PEcAn. |
| Authors: | Istem Fer [aut, cre] |
| Maintainer: | Istem Fer <[email protected]> |
| License: | BSD_3_clause + file LICENSE |
| Version: | 1.8.2.9000 |
| Built: | 2026-06-05 14:51:50 UTC |
| Source: | https://github.com/PecanProject/pecan |
Converts a met CF file to a model specific met file. The input files are calld <in.path>/<in.prefix>.YYYY.cf
met2model.STICS( in.path, in.prefix, outfolder, start_date, end_date, overwrite = FALSE, ... )met2model.STICS( in.path, in.prefix, outfolder, start_date, end_date, overwrite = FALSE, ... )
in.path |
path on disk where CF file lives |
in.prefix |
prefix for each file |
outfolder |
location where model specific output is written. |
start_date |
start date of the simulation |
end_date |
end date of the simulation |
overwrite |
logical: replace output files if they already exist? |
... |
other arguments passed to function |
results
Istem Fer
Convert STICS output into the NACP Intercomparison format (ALMA using netCDF)
model2netcdf.STICS( outdir, sitelat, sitelon, start_date, end_date, overwrite = FALSE )model2netcdf.STICS( outdir, sitelat, sitelon, start_date, end_date, overwrite = FALSE )
outdir |
Location of model output |
sitelat |
Latitude of the site |
sitelon |
Longitude of the site |
start_date |
Start time of the simulation |
end_date |
End time of the simulation |
overwrite |
Whether or not to overwrite existing output files |
Istem Fer
Function to translate pecan param names and units to stics names and units.
pecan2stics(trait.values)pecan2stics(trait.values)
trait.values |
trait.values, list |
translated list
Quentin Bell
Writes STICS configurations.
write.config.STICS(defaults, trait.values, settings, run.id)write.config.STICS(defaults, trait.values, settings, run.id)
defaults |
list of defaults to process |
trait.values |
vector of samples for a given trait |
settings |
list of settings from pecan settings file |
run.id |
id of run |
Requires a pft xml object, a list of trait values for a single model run, and the name of the file to create
configuration file for STICS for given run
Istem Fer